@@ -42,28 +42,24 @@
 
 #include "Table.h"
 #include "utils/text.h"
+#include "output/OutNormal.h"
+
 #include "utils/misc.h"
 #include "utils/messages.h"
 #include "utils/getopt.h"
 #include "utils/misc.h"
+#include "utils/prompt.h"
 
 #include "repos.h"
-#include "update.h"
-#include "solve-commit.h"
 #include "misc.h"
-#include "search.h"
-#include "info.h"
 
-#include "output/OutNormal.h"
-#include "output/OutXML.h"
 
 #include "utils/flags/zyppflags.h"
 #include "utils/flags/exceptions.h"
-#include "global-settings.h"
 
 #include "commands/search/search-packages-hinthack.h"
 #include "commands/help.h"
-#include "commands/subcommand.h"
+#include "utils/console.h"
 using namespace zypp;
 
 bool sigExitOnce = true;	// Flag to prevent nested calls to Zypper::immediateExit
@@ -88,13 +84,13 @@ void Zypper::assertZYppPtrGod()
     {
       // ask user whether to tell it to quit
       mbs_write_wrapped( Out::Info(out()) << "", _(
-	"PackageKit is blocking zypper. This happens if you have an"
-	" updater applet or other software management application using"
-	" PackageKit running."
+        "PackageKit is blocking zypper. This happens if you have an"
+        " updater applet or other software management application using"
+        " PackageKit running."
       ), 0, out().defaultFormatWidth( 100 ) );
 
       mbs_write_wrapped( Out::Info(out()) << "", _(
-	"We can ask PackageKit to interrupt the current action as soon as possible, but it depends on PackageKit how fast it will respond to this request."
+        "We can ask PackageKit to interrupt the current action as soon as possible, but it depends on PackageKit how fast it will respond to this request."
       ), 0, out().defaultFormatWidth( 100 ) );
 
       bool reply = read_bool_answer( PROMPT_PACKAGEKIT_QUIT, _("Ask PackageKit to quit?"), false );
@@ -102,15 +98,15 @@ void Zypper::assertZYppPtrGod()
       // tell it to quit
       while ( reply && still_locked )
       {
-	packagekit_suggest_quit();
-	::sleep( 2 );
-	if ( packagekit_running() )
-	{
-	  out().info(_("PackageKit is still running (probably busy)."));
-	  reply = read_bool_answer( PROMPT_PACKAGEKIT_QUIT, _("Try again?"), false );
-	}
-	else
-	  still_locked = false;
+        packagekit_suggest_quit();
+        ::sleep( 2 );
+        if ( packagekit_running() )
+        {
+          out().info(_("PackageKit is still running (probably busy)."));
+          reply = read_bool_answer( PROMPT_PACKAGEKIT_QUIT, _("Try again?"), false );
+        }
+        else
+          still_locked = false;
       }
     }
 
@@ -129,12 +125,12 @@ void Zypper::assertZYppPtrGod()
       { God = getZYpp(); }
       catch ( ZYppFactoryException & e )
       {
-	// this should happen only rarely, so no special handling here
-	ERR  << "still locked." << endl;
-	out().error( e.asString() );
+        // this should happen only rarely, so no special handling here
+        ERR  << "still locked." << endl;
+        out().error( e.asString() );
 
-	setExitCode( ZYPPER_EXIT_ZYPP_LOCKED );
-	ZYPP_THROW( ExitRequestException("ZYpp locked") );
+        setExitCode( ZYPPER_EXIT_ZYPP_LOCKED );
+        ZYPP_THROW( ExitRequestException("ZYpp locked") );
       }
     }
   }
@@ -162,11 +158,11 @@ namespace {
       PathInfo pi( dir_r );
       if ( pi.isExist() )
       {
-	if ( ! ( pi.isDir() && pi.userMayRWX() ) )
-	  mayuse = false;
+        if ( ! ( pi.isDir() && pi.userMayRWX() ) )
+          mayuse = false;
       }
       else
-	mayuse = userMayUseDir( dir_r.dirname() );
+        mayuse = userMayUseDir( dir_r.dirname() );
     }
     return mayuse;
   }
@@ -176,11 +172,11 @@ namespace {
 ///////////////////////////////////////////////////////////////////
 
 Zypper::Zypper()
-: _argc( 0 )
+: Application( std::make_shared<::Config>() )
+, _argc( 0 )
 , _argv( nullptr )
-, _out_ptr( nullptr )
+, _config( static_cast<::Config &>( Application::mutableConfig () ) )
 , _command( ZypperCommand::NONE )
-, _exitCode( ZYPPER_EXIT_OK )
 , _exitInfoCode( ZYPPER_EXIT_OK )
 , _running_shell( false )
 , _running_help( false )
@@ -192,7 +188,6 @@ Zypper::Zypper()
 
 Zypper::~Zypper()
 {
-  delete _out_ptr;
   MIL << "Zypper instance destroyed. Bye!" << endl;
 }
 
@@ -257,28 +252,9 @@ int Zypper::main( int argc, char ** argv )
 
 Out & Zypper::out()
 {
-  // PENDING SigINT? Some frequently called place to avoid exiting from within the signal handler?
-  immediateExitCheck();
-
-  if ( _out_ptr )
-    return *_out_ptr;
-
-  cerr << "uninitialized output writer" << endl;
-  ZYPP_THROW( ExitRequestException("no output writer") );
-}
-
-Out *Zypper::outputWriter()
-{
-  return _out_ptr;
-}
-
-void Zypper::setOutputWriter(Out *out)
-{
-  if ( _out_ptr ) {
-    delete _out_ptr;
-    _out_ptr = nullptr;
-  }
-  _out_ptr = out;
+    // PENDING SigINT? Some frequently called place to avoid exiting from within the signal handler?
+    immediateExitCheck();
+    return Application::out();
 }
 
 void print_command_help_hint( Zypper & zypper )
@@ -300,16 +276,15 @@ int Zypper::processGlobalOptions()
   MIL << "START" << endl;
 
   //setup the default output, this could be overridden by cli values
-  OutNormal * p = new OutNormal( _config.verbosity );
-  p->setUseColors( _config.do_colors );
-  setOutputWriter( p );
+  out().setVerbosity( _config.verbosity );
+  out().setUseColors( _config.do_colors );
 
   std::vector<ZyppFlags::CommandGroup> globalOpts = _config.cliOptions();
   int nextFlag = searchPackagesHintHack::argvCmdIdx = ZyppFlags::parseCLI( _argc, _argv, globalOpts );
 
   out().info( str::Format(_("Verbosity: %d")) % _config.verbosity , Out::HIGH );
   DBG << "Verbosity " << _config.verbosity << endl;
-  DBG << "Output type " << _out_ptr->type() << endl;
+  DBG << "Output type " << out().type() << endl;
 
   // ======== other global options ========
   {
