@@ -6,6 +6,7 @@
 #include <zypp/base/LogTools.h>
 #include <zypp/base/LogControl.h>
 #include <zypp/base/Backtrace.h>
+#include <zypp/base/Regex.h>
 
 #include "main.h"
 #include "Zypper.h"
@@ -19,6 +20,17 @@
 #include "output/OutNormal.h"
 #include "utils/messages.h"
 
+namespace env
+{
+  std::string SUDO_USER()
+  {
+     std::string ret;
+     if ( const char * env = ::getenv( "SUDO_USER" ) )
+       ret = env;
+     return ret;
+  }
+}
+
 void signal_handler( int sig )
 {
   Zypper & zypper( Zypper::instance() );
@@ -83,9 +95,21 @@ int main( int argc, char **argv )
 {
   struct Bye {
     ~Bye() {
-      MIL << "===== Exiting main() =====" << endl;
+      MIL << "===== Exiting main("<<exitcode<<") =====" << endl;
     }
-  } say_goodbye __attribute__ ((__unused__));
+    int exitcode = -1;
+  } say_goodbye;
+
+  // bsc#1183589: Protect against strict/relaxed user umask via sudo
+  bool sudo = false;	// will be mentioned in the log
+  if ( geteuid() == 0 ) {
+    std::string sudouser { env::SUDO_USER() };
+    if ( ! sudouser.empty() ) {
+      sudo = true;
+      mode_t omask = ::umask( 0022 );
+      ::umask( omask&0022 );
+    }
+  }
 
   // set locale
   setlocale( LC_ALL, "" );
@@ -99,18 +123,16 @@ int main( int argc, char **argv )
   base::LogControl::instance().logfile( logfile );
 
   MIL << "===== Hi, me zypper " VERSION << endl;
-  dumpRange( MIL, argv, argv+argc, "===== ", "'", "' '", "'", " =====" ) << endl;
-
-  OutNormal out( Out::QUIET );
-
+  dumpRange( MIL, argv, argv+argc, (sudo ? "===== 'sudo' ": "===== "), "'", "' '", "'", " =====" ) << endl;
+  Zypper & zypper( Zypper::instance() );
 
   if ( ::signal( SIGINT, signal_handler ) == SIG_ERR )
-    out.error("Failed to set SIGINT handler.");
+    zypper.out().error("Failed to set SIGINT handler.");
   if ( ::signal (SIGTERM, signal_handler ) == SIG_ERR )
-    out.error("Failed to set SIGTERM handler.");
+    zypper.out().error("Failed to set SIGTERM handler.");
 
   if ( ::signal( SIGPIPE, signal_nopipe ) == SIG_ERR )
-    out.error("Failed to set SIGPIPE handler.");
+    zypper.out().error("Failed to set SIGPIPE handler.");
 
   try
   {
@@ -125,20 +147,20 @@ int main( int argc, char **argv )
   catch ( const Exception & e )
   {
     ZYPP_CAUGHT( e );
-    out.error( e, "Failed to initialize zypper callbacks." );
-    report_a_bug( out );
+    zypper.out().error( e, "Failed to initialize zypper callbacks." );
+    report_a_bug( zypper.out() );
     return ZYPPER_EXIT_ERR_BUG;
   }
   catch (...)
   {
-    out.error( "Failed to initialize zypper callbacks." );
+    zypper.out().error( "Failed to initialize zypper callbacks." );
     ERR << "Failed to initialize zypper callbacks." << endl;
-    report_a_bug( out );
+    report_a_bug( zypper.out() );
     return ZYPPER_EXIT_ERR_BUG;
   }
 
-  Zypper & zypper( Zypper::instance() );
-  int exitcode = zypper.main( argc, argv );
+  int & exitcode { say_goodbye.exitcode };
+  exitcode = zypper.main( argc, argv );
   if ( !exitcode )
     exitcode = zypper.exitInfoCode();	// propagate refresh errors even if main action succeeded
   return exitcode;
