@@ -7,6 +7,7 @@
 
 #include <iostream>
 #include <sstream>
+#include <optional>
 
 #include <zypp/ZYppFactory.h>
 #include <zypp/base/Logger.h>
@@ -24,6 +25,7 @@
 #include "utils/prompt.h"	// Continue? and solver problem prompt
 #include "utils/pager.h"	// to view the summary
 #include "global-settings.h"
+#include "CommitSummary.h"
 
 #include "solve-commit.h"
 #include "commands/needs-rebooting.h"
@@ -31,6 +33,36 @@
 using namespace zypp;
 extern ZYpp::Ptr God;
 
+///////////////////////////////////////////////////////////////////
+/// bsc#1183268: Patch reboot-needed flag overrules included packages.
+///
+/// Prevent creation of /run/reboot-needed by packages if patches
+/// overruled them (i.e. claim no reboot needed).
+///////////////////////////////////////////////////////////////////
+class PatchRebootRulesWatchdog
+{
+  PatchRebootRulesWatchdog( const PatchRebootRulesWatchdog & ) = delete;
+  PatchRebootRulesWatchdog & operator=( const PatchRebootRulesWatchdog & ) = delete;
+public:
+  PatchRebootRulesWatchdog( bool on_r )
+  {
+    PathInfo watch { Pathname(Zypper::instance().config().root_dir)/"/run/reboot-needed" };
+    MIL << "Initial reboot-needed: " << watch << endl;
+    if ( on_r && not watch.isExist() )
+      _watch = watch.path(); // take care it stays absent after commit
+  }
+  ~PatchRebootRulesWatchdog()
+  {
+    if ( not _watch.empty() ) {
+      MIL << "PATCH_REBOOT_RULES overrules reboot-needed" << endl;
+      filesystem::unlink( _watch );
+    }
+  }
+private:
+  Pathname _watch;
+};
+
+
 //! @return true to retry solving now,
 //!         false to cancel,
 //!         indeterminate to continue
@@ -339,8 +371,6 @@ static void set_solver_flags( Zypper & zypper )
   set_no_recommends( zypper );
   set_ignore_recommends_of_installed( zypper );
 
-  // Beware: While zypper calls resolve() once just to compute the PPP status,
-  // solve_with_update must be false until the command passed the initialization!
   God->resolver()->setUpdateMode( zypper.runtimeData().solve_with_update );
 
   const auto &solverSettings = SolverSettings::instance();
@@ -454,22 +484,57 @@ static void make_solver_test_case( Zypper & zypper )
   }
 }
 
-ZYppCommitPolicy get_commit_policy( Zypper & zypper, DownloadMode dlMode_r )
+SolveAndCommitPolicy::SolveAndCommitPolicy( )
 {
-  ZYppCommitPolicy policy;
+  // set up the various commit flags which are scattered all over the place
+  _zyppCommitPolicy
+    .dryRun( DryRunSettings::instance().isEnabled() )
+    .replaceFiles( FileConflictPolicy::instance()._replaceFiles )
+    .allowDowngrade( false );
 
-  if ( DryRunSettings::instance().isEnabled() )
-    policy.dryRun(true);
-
-  if ( dlMode_r != DownloadDefault )
-    policy.downloadMode( dlMode_r );
-
-  policy.syncPoolAfterCommit( policy.dryRun() ? false : zypper.runningShell() );
-
-  MIL << "Using commit policy: " << policy << endl;
-  return policy;
+  _zyppCommitPolicy.downloadMode( DownloadDefault );
+  _zyppCommitPolicy.syncPoolAfterCommit( _zyppCommitPolicy.dryRun() ? false : Zypper::instance().runningShell() );
 }
 
+bool SolveAndCommitPolicy::forceCommit() const
+{ return _forceCommit; }
+
+SolveAndCommitPolicy &SolveAndCommitPolicy::forceCommit(bool enable)
+{ _forceCommit = enable; return *this; }
+
+const Summary::ViewOptions &SolveAndCommitPolicy::summaryOptions() const
+{ return _summaryOptions; }
+
+SolveAndCommitPolicy &SolveAndCommitPolicy::summaryOptions( Summary::ViewOptions options )
+{ _summaryOptions = options; return *this; }
+
+ZYppCommitPolicy &SolveAndCommitPolicy::zyppCommitPolicy()
+{ return _zyppCommitPolicy; }
+
+const ZYppCommitPolicy &SolveAndCommitPolicy::zyppCommitPolicy() const
+{ return _zyppCommitPolicy; }
+
+SolveAndCommitPolicy &SolveAndCommitPolicy::zyppCommitPolicy( ZYppCommitPolicy policy )
+{ _zyppCommitPolicy = policy; return *this; }
+
+SolveAndCommitPolicy & SolveAndCommitPolicy::downloadMode( DownloadMode dlMode )
+{
+  // set up the DownloadMode and emit a info if we auto override it due to singletrans
+  // the libzypp code will do the same but only emit a warning to the logs, lets be a bit more verbose
+  if ( dlMode != _zyppCommitPolicy.downloadMode() ) {
+
+    if ( dlMode == DownloadAsNeeded && _zyppCommitPolicy.singleTransModeEnabled() ) {
+      Zypper::instance().out().warning( _("DownloadAsNeeded can not be used with ZYPP_SINGLE_RPMTRANS=1, falling back to DownloadInAdvance") );
+      dlMode = DownloadInAdvance;
+    }
+    _zyppCommitPolicy.downloadMode( dlMode );
+  }
+  return *this;
+}
+
+DownloadMode SolveAndCommitPolicy::downloadMode() const
+{ return _zyppCommitPolicy.downloadMode(); }
+
 /** fate #300763
  * This is called after each commit to notify user about running processes that
  * use libraries or other files that have been removed since their execution.
@@ -478,7 +543,7 @@ static void notify_processes_using_deleted_files( Zypper & zypper )
 {
   if ( ! zypper.config().psCheckAccessDeleted ) {
     zypper.out().info( str::form(_("Check for running processes using deleted libraries is disabled in zypper.conf. Run '%s' to check manually."),
-				 "zypper ps -s" ) );
+                                 "zypper ps -s" ) );
   } else {
     zypper.out().info(_("Checking for running processes using deleted libraries..."), Out::HIGH );
     CheckAccessDeleted checker( false ); // wait for explicit call to check()
@@ -493,7 +558,7 @@ static void notify_processes_using_deleted_files( Zypper & zypper )
         if ( e.historySize() )
     zypper.out().error( e, _("Check failed:") );
         else
-    zypper.out().info( str::Str() << ( ColorContext::MSG_WARNING << _("Skip check:") ) << " " << e.asUserString() );
+            zypper.out().info( str::Str() << ( ColorContext::MSG_WARNING << _("Skip check:") ) << " " << e.asUserString() );
       }
     }
 
@@ -557,16 +622,16 @@ static void show_update_messages( Zypper & zypper, const UpdateNotifications & m
  *  ZYPPER_EXIT_INF_RESTART_NEEDED - if one of patches to be installed needs package manager restart
  */
 
-void solve_and_commit (Zypper & zypper , Summary::ViewOptions summaryOptions_r, DownloadMode dlMode_r , SolveAndCommitPolicy commitPolicy_r )
+void solve_and_commit ( Zypper &zypper, SolveAndCommitPolicy policy )
 {
   bool need_another_solver_run = true;
-  bool dryRunEtc = DryRunSettings::instance().isEnabled() || ( dlMode_r == DownloadOnly );
+  bool dryRunEtc = policy.zyppCommitPolicy().dryRun() || ( policy.zyppCommitPolicy().downloadMode() == DownloadOnly );
   do
   {
     // CALL SOLVER
 
-    // e.g. doUpdate unsets this flag, no need for another solving
-    if ( zypper.runtimeData().solve_before_commit )
+    // doUpdate sets this flag, if no other jobs are to be included
+    if ( not zypper.runtimeData().solve_update_only )
     {
       MIL << "solving..." << endl;
 
@@ -597,6 +662,10 @@ void solve_and_commit (Zypper & zypper , Summary::ViewOptions summaryOptions_r,
           return;
         }
       }
+    } else {
+      MIL << "Computing package update..." << endl;
+      set_solver_flags( zypper );   // bsc#1201972: make sure 'up' also respects solver options
+      zypp::getZYpp()->resolver()->doUpdate();
     }
 
     if ( SolverSettings::instance()._debugSolver )
@@ -609,7 +678,7 @@ void solve_and_commit (Zypper & zypper , Summary::ViewOptions summaryOptions_r,
 
     // SHOW SUMMARY
 
-    Summary summary( God->pool(), summaryOptions_r );
+    Summary summary( God->pool(), policy.summaryOptions() );
 
     if ( zypper.out().verbosity() == Out::HIGH )
       summary.setViewOption( Summary::SHOW_VERSION );
@@ -622,7 +691,7 @@ void solve_and_commit (Zypper & zypper , Summary::ViewOptions summaryOptions_r,
     else
       summary.unsetViewOption( Summary::SHOW_UNSUPPORTED );
 
-    if ( dlMode_r == DownloadOnly )
+    if ( policy.zyppCommitPolicy().downloadMode() == DownloadOnly )
       summary.setDownloadOnly( true );
 
     // show the summary
@@ -638,11 +707,11 @@ void solve_and_commit (Zypper & zypper , Summary::ViewOptions summaryOptions_r,
     {
       if ( zypper.command() == ZypperCommand::VERIFY )
         zypper.out().info(_("Some of the dependencies of installed packages are broken."
-	" In order to fix these dependencies, the following actions need to be taken:") );
+        " In order to fix these dependencies, the following actions need to be taken:") );
 
       // check root user
       if ( zypper.command() == ZypperCommand::VERIFY && geteuid() != 0
-	&& !zypper.config().changedRoot )
+        && !zypper.config().changedRoot )
       {
         zypper.out().error(_("Root privileges are required to fix broken package dependencies.") );
         zypper.setExitCode( ZYPPER_EXIT_ERR_PRIVILEGES );
@@ -653,7 +722,7 @@ void solve_and_commit (Zypper & zypper , Summary::ViewOptions summaryOptions_r,
 
       bool show_p_option = ( summary.packagesToRemove() && ( zypper.command() == ZypperCommand::INSTALL
                                                           || zypper.command() == ZypperCommand::UPDATE) )
-			|| ( summary.packagesToGetAndInstall() && zypper.command() == ZypperCommand::REMOVE );
+                        || ( summary.packagesToGetAndInstall() && zypper.command() == ZypperCommand::REMOVE );
 
       PromptOptions popts;
       // translators: These are the "Continue?" prompt options corresponding to
@@ -765,23 +834,23 @@ void solve_and_commit (Zypper & zypper , Summary::ViewOptions summaryOptions_r,
 
       if ( !do_commit )
       {
-	zypper.setExitCode( ZYPPER_EXIT_ERR_ZYPP );
-	return;
+        zypper.setExitCode( ZYPPER_EXIT_ERR_ZYPP );
+        return;
       }
       else
       {
-	// COMMIT
+        // COMMIT
 
         if ( !confirm_licenses( zypper ) )
-	{
-	  zypper.setExitCode( ZYPPER_EXIT_ERR_ZYPP );
+        {
+          zypper.setExitCode( ZYPPER_EXIT_ERR_ZYPP );
           return;
-	}
+        }
 
+        std::optional<ZYppCommitResult> result;
         try
         {
           RuntimeData & gData = Zypper::instance().runtimeData();
-          gData.show_media_progress_hack = true;
           // Total packages to download & install.
           // To be used to write overall progress of retrieving packages.
           gData.commit_pkgs_total = summary.packagesToGetAndInstall();
@@ -789,40 +858,44 @@ void solve_and_commit (Zypper & zypper , Summary::ViewOptions summaryOptions_r,
           // To be used to show overall progress of rpm transactions.
           gData.rpm_pkgs_total = God->resolver()->getTransaction().actionSize();
           gData.rpm_pkg_current = 0;
-	  gData.entered_commit = true;	// bsc#946750 - give ZYPPER_EXIT_ERR_COMMIT priority over ZYPPER_EXIT_ON_SIGNAL
+          gData.entered_commit = true;	// bsc#946750 - give ZYPPER_EXIT_ERR_COMMIT priority over ZYPPER_EXIT_ON_SIGNAL
 
-	  MIL << "committing..." << endl;
-	  if ( zypper.out().verbosity() >= Out::HIGH )
-	  {
-	    std::ostringstream s;
-	    s << _("committing");
-	    if ( DryRunSettings::instance().isEnabled() )
-	      s << " " << _("(dry run)");
-	    zypper.out().info( s.str(), Out::HIGH );
-	  }
+          MIL << "committing..." << endl;
+          if ( zypper.out().verbosity() >= Out::HIGH )
+          {
+            std::ostringstream s;
+            s << _("committing");
+            if ( policy.zyppCommitPolicy().dryRun() )
+              s << " " << _("(dry run)");
+            zypper.out().info( s.str(), Out::HIGH );
+          }
 
-          ZYppCommitResult result = God->commit( get_commit_policy( zypper, dlMode_r ) );
-          gData.show_media_progress_hack = false;
-	  gData.entered_commit = false;
+          // bsc#1183268: Patch reboot-needed flag overrules included packages.
+          PatchRebootRulesWatchdog guard { summary.hasViewOption( Summary::PATCH_REBOOT_RULES ) && not summary.needMachineReboot() };
 
-	  if ( !result.allDone() && !( dryRunEtc && result.noError() ) )
-	  { zypper.setExitCode( result.attemptToModify() ? ZYPPER_EXIT_ERR_COMMIT : ZYPPER_EXIT_ERR_ZYPP ); }	// error message comes later....
+          MIL << "Using commit policy: " << policy.zyppCommitPolicy() << endl;
+          result = God->commit( policy.zyppCommitPolicy() );
+
+          gData.entered_commit = false;
+
+          if ( !result->allDone() && !( dryRunEtc && result->noError() ) )
+          { zypper.setExitCode( result->attemptToModify() ? ZYPPER_EXIT_ERR_COMMIT : ZYPPER_EXIT_ERR_ZYPP ); }	// error message comes later....
 
           MIL << endl << "DONE" << endl;
-	  if ( zypper.out().verbosity() >= Out::HIGH )
-	  {
-	    std::ostringstream s;
-	    s << result;
-	    zypper.out().info( s.str(), Out::HIGH );
-	  }
+          if ( zypper.out().verbosity() >= Out::HIGH )
+          {
+            std::ostringstream s;
+            s << *result;
+            zypper.out().info( s.str(), Out::HIGH );
+          }
 
-          show_update_messages( zypper, result.updateMessages() );
+          show_update_messages( zypper, result->updateMessages() );
         }
         catch ( const media::MediaException & e )
         {
           ZYPP_CAUGHT( e );
           zypper.out().error( e, _("Problem retrieving the package file from the repository:"),
-			      _("Please see the above error message for a hint.") );
+                              _("Please see the above error message for a hint.") );
           zypper.setExitCode( ZYPPER_EXIT_ERR_COMMIT );
           return;
         }
@@ -830,30 +903,30 @@ void solve_and_commit (Zypper & zypper , Summary::ViewOptions summaryOptions_r,
         {
           ZYPP_CAUGHT( e );
           bool refresh_needed = false;
-	  if ( !e.info().baseUrlsEmpty() )
-	  {
-	    try
-	    {
-	      RepoManager manager( zypper.config().rm_options );
-	      for( RepoInfo::urls_const_iterator it = e.info().baseUrlsBegin(); it != e.info().baseUrlsEnd(); ++it )
-	      {
-		if ( manager.checkIfToRefreshMetadata( e.info(), *it, RepoManager::RefreshForced ) == RepoManager::REFRESH_NEEDED )
-		{
-		  refresh_needed = true;
-		  break;
-		}
-	      }
-	    }
-	    catch ( const Exception & )
-	    { DBG << "check if to refresh exception caught, ignoring" << endl; }
-	  }
+          if ( !e.info().baseUrlsEmpty() )
+          {
+            try
+            {
+              RepoManager manager( zypper.config().rm_options );
+              for( RepoInfo::urls_const_iterator it = e.info().baseUrlsBegin(); it != e.info().baseUrlsEnd(); ++it )
+              {
+                if ( manager.checkIfToRefreshMetadata( e.info(), *it, RepoManager::RefreshForced ) == RepoManager::REFRESH_NEEDED )
+                {
+                  refresh_needed = true;
+                  break;
+                }
+              }
+            }
+            catch ( const Exception & )
+            { DBG << "check if to refresh exception caught, ignoring" << endl; }
+          }
 
-	  std::string hint;
+          std::string hint;
           if ( refresh_needed )
-	    // translators: the first %s is 'zypper refresh' and the second is repo alias
-	    hint = str::Format(_("Repository '%s' is out of date. Running '%s' might help.")) % e.info().alias() % "zypper refresh";
-	  else
-	    hint = _("Please see the above error message for a hint.");
+            // translators: the first %s is 'zypper refresh' and the second is repo alias
+            hint = str::Format(_("Repository '%s' is out of date. Running '%s' might help.")) % e.info().alias() % "zypper refresh";
+          else
+            hint = _("Please see the above error message for a hint.");
           zypper.out().error( e, _("Problem retrieving the package file from the repository:"), hint );
           zypper.setExitCode( ZYPPER_EXIT_ERR_COMMIT );
           return;
@@ -883,50 +956,65 @@ void solve_and_commit (Zypper & zypper , Summary::ViewOptions summaryOptions_r,
         }
 
         if ( zypper.exitCode() != ZYPPER_EXIT_OK )
-	{
-	  zypper.out().error(_("Installation has completed with error.") );
-	  if ( zypper.exitCode() == ZYPPER_EXIT_ERR_COMMIT )
-	    zypper.out().error( str::Format(_("You may run '%1%' to repair any dependency problems.")) % "zypper verify" );
-	}
-	else
-	{
-	  // install any pending source packages
-	  //! \todo This won't be necessary once we get a new solver flag
-	  //! for installing source packages without their build deps
-	  if ( !zypper.runtimeData().srcpkgs_to_install.empty() )
-	    install_src_pkgs( zypper, dlMode_r );
+        {
+          if ( result && result->singleTransactionMode() ) {
 
-	  // set return value to 'reboot needed'
-	  if ( summary.needMachineReboot() )
-	  {
-	    zypper.setExitCode( ZYPPER_EXIT_INF_REBOOT_NEEDED );
-	    zypper.out().warning(_("One of the installed patches requires a reboot of"
-	    " your machine. Reboot as soon as possible."), Out::QUIET );
-	  }
-	  // set return value to 'restart needed' (restart of package manager)
-	  // however, 'reboot needed' takes precedence
-	  else if ( zypper.exitCode() != ZYPPER_EXIT_INF_REBOOT_NEEDED && summary.needPkgMgrRestart() )
-	  {
-	    zypper.setExitCode( ZYPPER_EXIT_INF_RESTART_NEEDED );
-	    zypper.out().warning(_("One of the installed patches affects the package"
-	    " manager itself. Run this command once more to install any other"
-	    " needed patches." ), Out::QUIET, Out::TYPE_NORMAL ); // don't show this to machines
-	  }
-	}
+            CommitSummary cSummary( *result );
+            if ( zypper.out().verbosity() == Out::HIGH )
+              cSummary.setViewOption( CommitSummary::ViewOptions( CommitSummary::SHOW_VERSION | CommitSummary::SHOW_REPO ) );
+            else if ( zypper.out().verbosity() == Out::DEBUG )
+              cSummary.setViewOption( CommitSummary::SHOW_ALL );
+
+            // show the summary
+            if ( zypper.out().type() == Out::TYPE_XML )
+              cSummary.dumpAsXmlTo( cout );
+            else
+              cSummary.dumpTo( cout );
+
+          } else {
+            CommitSummary::showBasicErrorMessage( zypper );
+          }
+
+        }
+        else
+        {
+          // install any pending source packages
+          //! \todo This won't be necessary once we get a new solver flag
+          //! for installing source packages without their build deps
+          if ( !zypper.runtimeData().srcpkgs_to_install.empty() )
+            install_src_pkgs( zypper, policy.zyppCommitPolicy().downloadMode() );
+
+          // set return value to 'reboot needed'
+          if ( summary.needMachineReboot() )
+          {
+            zypper.setExitCode( ZYPPER_EXIT_INF_REBOOT_NEEDED );
+            zypper.out().warning(_("One of the installed patches requires a reboot of"
+            " your machine. Reboot as soon as possible."), Out::QUIET );
+          }
+          // set return value to 'restart needed' (restart of package manager)
+          // however, 'reboot needed' takes precedence
+          else if ( zypper.exitCode() != ZYPPER_EXIT_INF_REBOOT_NEEDED && summary.needPkgMgrRestart() )
+          {
+            zypper.setExitCode( ZYPPER_EXIT_INF_RESTART_NEEDED );
+            zypper.out().warning(_("One of the installed patches affects the package"
+            " manager itself. Run this command once more to install any other"
+            " needed patches." ), Out::QUIET, Out::TYPE_NORMAL ); // don't show this to machines
+          }
+        }
 
         // check for running services (fate #300763)
         if ( !( zypper.config().changedRoot || dryRunEtc )
-	  && ( summary.packagesToRemove() || summary.packagesToUpgrade() || summary.packagesToDowngrade() ) )
-	{
+          && ( summary.packagesToRemove() || summary.packagesToUpgrade() || summary.packagesToDowngrade() ) )
+        {
           notify_processes_using_deleted_files( zypper );
-	}
+        }
       }
     }
     // noting to do
     else
     {
       //used to make sure locales and metadata is written even if there is no packages to be installed/removed
-      if ( commitPolicy_r == ForceCommit )
+      if ( policy.forceCommit() )
         God->commit( ZYppCommitPolicy() );
 
       if ( zypper.command() == ZypperCommand::VERIFY )
