@@ -21,181 +21,14 @@
 
 #include "prompt.h"
 
-// ----------------------------------------------------------------------------
 
-PromptOptions::PromptOptions( StrVector options_r, unsigned defaultOpt_r )
-{ setOptions( std::move(options_r), defaultOpt_r ); }
-
-PromptOptions::PromptOptions( const std::string & optionstr_r, unsigned defaultOpt_r )
-{ setOptions( optionstr_r, defaultOpt_r ); }
-
-// ----------------------------------------------------------------------------
-
-PromptOptions::~PromptOptions()
-{}
-
-// ----------------------------------------------------------------------------
-
-void PromptOptions::setOptions( StrVector options_r, unsigned defaultOpt_r )
-{
-  _options.swap( options_r );
-  if ( _options.size() <= defaultOpt_r )
-  {
-    INT << "Invalid default option index " << defaultOpt_r << endl;
-    _default = 0;
-  }
-  else
-    _default = defaultOpt_r;
-}
-
-void PromptOptions::setOptions( const std::string & optionstr_r, unsigned defaultOpt_r )
-{
-  StrVector options;
-  str::split( optionstr_r, back_inserter(options), "/" );
-  setOptions( std::move(options), defaultOpt_r );
-}
-
-ColorString PromptOptions::optionString() const
-{
-  bool hidden = false;	// have enabled options not shown at the prompt (/...)?
-  unsigned shown = 0;
-  unsigned showmax = ( _shown_count < 0 ? _options.size() : (unsigned)_shown_count );
-
-  std::ostringstream str;
-  str << "[";
-
-  const char * slash = "";	// "/" after the 1st option
-  for ( unsigned idx = 0; idx < _options.size(); ++idx )
-  {
-    if ( isDisabled(idx) )
-      continue;
-
-    if ( shown < showmax )
-    {
-      str << slash << ( ColorContext::PROMPT_OPTION << _options[idx] );
-      if ( !shown ) slash = "/";
-      ++shown;
-    }
-    else
-    {
-      hidden = true;
-      break;	// don't mind how many
-    }
-  }
-
-  if ( hidden || !_opt_help.empty() )
-  {
-    str << slash << ( hidden ? "..." : "" ) << ( ColorContext::PROMPT_OPTION << "?" );
-    if ( hidden )
-      // translators: Press '?' to see all options embedded in this prompt: "Continue? [y/n/? shows all options] (y):"
-      str << " " << _("shows all options");
-  }
-
-  str << "]";
-
-  if ( !_options.empty() )
-    str << " (" << ( ColorContext::PROMPT_OPTION << _options[_default] ) << ")";
-
-  return ColorString( str.str() );
-}
-
-
-void PromptOptions::setOptionHelp( unsigned opt, const std::string & help_str )
-{
-  if ( help_str.empty() )
-    return;
-
-  if ( opt >= _options.size() )
-  {
-    WAR << "attempt to set option help for non-existing option."
-        << " text: " << help_str << endl;
-    return;
-  }
-
-  if ( opt >= _opt_help.capacity() )
-    _opt_help.reserve( _options.size() );
-  if ( opt >= _opt_help.size( ))
-    _opt_help.resize( _options.size() );
-
-  _opt_help[opt] = help_str;
-}
-
-std::vector<int> PromptOptions::getReplyMatches( const std::string & reply_r ) const
-{
-  std::vector<int> ret;
-
-  // #NUM ? (direct index into option vector)
-  if ( reply_r[0] == '#' && reply_r[1] != '\0' )
-  {
-    unsigned num = 0;	// -1 : if no match
-    for ( const char * cp = reply_r.c_str()+1; *cp; ++cp )
-    {
-      if ( '0' <= *cp && *cp <= '9' )
-      {
-	num *= 10;
-	num += (*cp-'0');
-      }
-      else
-      {
-	num = unsigned(-1);
-	break;
-      }
-    }
-
-    if ( num != unsigned(-1) )
-    {
-      // userland counting! #1 is the 1st (enabled) option (#0 will never match)
-      if ( num != 0 )
-      {
-	for ( unsigned i = 0; i < _options.size(); ++i )
-	{
-	  if ( isDisabled(i) )
-	    continue;
-
-	  if ( --num == 0 )
-	  {
-	    ret.push_back( i );
-	    break;
-	  }
-	}
-      }
-      return ret;	// a match - good or bad - will be eaten
-    }
-    // no match falls through....
-  }
-
-  std::string lreply { str::toLower( reply_r ) };
-  for ( unsigned i = 0; i < _options.size(); ++i )
-  {
-    if ( isDisabled(i) )
-      continue;
-
-    if ( str::hasPrefix( str::toLower( _options[i] ), lreply ) )
-      ret.push_back( i );
-  }
-
-  return ret;
-}
-
-std::string PromptOptions::replyMatchesStr( const std::vector<int> & matches_r ) const
-{
-  str::Str str;
-  const char * sep = "(";	// "," after the 1st option
-  for ( unsigned idx : matches_r )
-  {
-    str << sep << _options[idx];
-    if ( *sep != ',' ) sep =",";
-  }
-  return str << ")";
-}
-
-
-bool PromptOptions::isYesNoPrompt() const
-{ return _options.size() == 2 && _options[0] == _("yes") && _options[1] == _("no"); }
 
 // ----------------------------------------------------------------------------
 
 //! \todo The default values seems to be useless - we always want to auto-return 'retry' in case of no user input.
+//!
+//! README first: This function seems to be part of media.cc, it expects Retry being given as default, this also explains why it
+//! unconditionally writes out strings like "trying again".
 int read_action_ari_with_timeout( PromptId pid, unsigned timeout, int default_action )
 {
   Zypper & zypper( Zypper::instance() );
@@ -268,8 +101,8 @@ int read_action_ari_with_timeout( PromptId pid, unsigned timeout, int default_ac
     }
 
     std::string msg = str::Format(PL_("Autoselecting '%s' after %u second.",
-				      "Autoselecting '%s' after %u seconds.",
-				      timeout)) % poptions.options()[default_action] % timeout;
+                                      "Autoselecting '%s' after %u seconds.",
+                                      timeout)) % poptions.options()[default_action] % timeout;
 
     if ( zypper.out().type() == Out::TYPE_XML )
       zypper.out().info( msg );	// maybe progress??
@@ -336,7 +169,7 @@ unsigned get_prompt_reply( Zypper & zypper, PromptId pid, const PromptOptions &
     // print the reply for convenience (only for normal output)
     if ( ! zypper.config().machine_readable )
       zypper.out().info( poptions.options()[poptions.defaultOpt()],
-			 Out::QUIET, Out::TYPE_NORMAL );
+                         Out::QUIET, Out::TYPE_NORMAL );
     MIL << "running non-interactively, returning " << poptions.options()[poptions.defaultOpt()] << endl;
     return poptions.defaultOpt();
   }
@@ -368,9 +201,9 @@ unsigned get_prompt_reply( Zypper & zypper, PromptId pid, const PromptOptions &
     {
       WAR << "Could not read the answer - bad stream or EOF" << endl;
       zypper.out().error( _("Cannot read input: bad stream or EOF."),
-			  str::Format(_("If you run zypper without a terminal, use '%s' global\n"
-			  "option to make zypper use default answers to prompts."))
-			  % "--non-interactive" );
+                          str::Format(_("If you run zypper without a terminal, use '%s' global\n"
+                          "option to make zypper use default answers to prompts."))
+                          % "--non-interactive" );
       zypper.setExitCode(ZYPPER_EXIT_ERR_ZYPP);
       ZYPP_THROW( ExitRequestException("Cannot read input. Bad stream or EOF.") );
     }
@@ -418,8 +251,8 @@ unsigned get_prompt_reply( Zypper & zypper, PromptId pid, const PromptOptions &
     {
       s << " "
         // translators: the %s are: 'y', 'yes' (translated), 'n', and 'no' (translated).
-	<< str::Format(_("Enter '%s' for '%s' or '%s' for '%s' if nothing else works for you."))
-	   % "y" % _("yes") % "n" % _("no");
+        << str::Format(_("Enter '%s' for '%s' or '%s' for '%s' if nothing else works for you."))
+           % "y" % _("yes") % "n" % _("no");
     }
     else if ( loopcnt > 1 )
     {
